# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"URL": "constants.ipynb",
         "URLHM": "constants.ipynb",
         "URLHM2": "constants.ipynb",
         "ACAO_DESCRIPTION": "constants.ipynb",
         "ACAO_TRACKER": "constants.ipynb",
         "FIELDS": "constants.ipynb",
         "CUSTOM_IDS": "constants.ipynb",
         "SITUACAO": "constants.ipynb",
         "DICT_FIELDS": "constants.ipynb",
         "JSON_FIELDS": "constants.ipynb",
         "CLASSE": "constants.ipynb",
         "TIPO": "constants.ipynb",
         "STATUS": "constants.ipynb",
         "SERVICOS": "constants.ipynb",
         "PF": "constants.ipynb",
         "PROCEDIMENTOS": "constants.ipynb",
         "ID2FIELD": "constants.ipynb",
         "HM2PROD": "constants.ipynb",
         "FIELD2ID": "constants.ipynb",
         "ESTADOS": "constants.ipynb",
         "journal2table": "redmine.ipynb",
         "value_text_string": "redmine.ipynb",
         "check_update": "redmine.ipynb",
         "view_string": "redmine.ipynb",
         "valida_fiscaliza": "redmine.ipynb",
         "issue_type": "redmine.ipynb",
         "hm2prod": "redmine.ipynb",
         "validar_dicionario": "redmine.ipynb",
         "auth_user": "redmine.ipynb",
         "issue2users": "redmine.ipynb",
         "insp2acao": "redmine.ipynb",
         "detalhar_inspecao": "redmine.ipynb",
         "atualiza_fiscaliza": "redmine.ipynb",
         "relatar_inspecao": "redmine.ipynb"}

modules = ["constants.py",
           "redmine.py"]

doc_url = "https://ronaldokun.github.io/fiscaliza/"

git_url = "https://github.com/ronaldokun/fiscaliza/tree/master/"

def custom_doc_links(name): return None
